PCB Environment: PCBoardMesh Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures | Public Member Functions | Static Public Attributes
PCBoardMesh Class Reference

## Data Structures
struct | IndexRange

## Public Member Functions
| PCBoardMesh (const PCBoard &, int z, char mask=RENDER_MASK_ALL)
void | update ()
void | draw (const Camera &)
void | drawExtra ()
void | setCamera (const Camera &)
void | setExtraSet (const std::set< Object * > *)
void | setLineWidth (float w)
void | setLineAlpha (float a)
void | setFillAlpha (float a)

## Static Public Attributes
static constexpr const GLushort | RestartIndex = 0xffff
static constexpr const char | RENDER_MASK_COMPONENTS = 0x1
static constexpr const char | RENDER_MASK_PINS = 0x2
static constexpr const char | RENDER_MASK_ALL = 0x3

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/PCBoardMesh.hpp